@@ -26,7 +26,7 @@ use warnings;
 
 use Buildd qw(lock_file unlock_file unset_env exitstatus send_mail);
 use Buildd::Base;
-use Buildd::Conf;
+use Buildd::Conf qw();
 use Sbuild::ChrootRoot;
 use Sbuild::DB::Client;
 
