@@ -53,6 +53,7 @@ sub setup {
 
     if (!$self->get('SETUP')) {
 	my $host = Sbuild::ChrootRoot->new($self->get('Config'));
+	$host->begin_session();
 	$host->set('Log Stream', $self->get('Log Stream'));
 	$self->set('Host', $host);
 	$self->set('SETUP', 1);
@@ -85,7 +86,6 @@ sub run_query {
     my $pipe = $self->get('Host')->run_command(
 	{ COMMAND => [@command],
 	  USER => $self->get_conf('USERNAME'),
-	  CHROOT => 0,
 	  PRIORITY => 0,
 	});
 }
@@ -100,7 +100,6 @@ sub pipe_query {
     my $pipe = $self->get('Host')->pipe_command(
 	{ COMMAND => [@command],
 	  USER => $self->get_conf('USERNAME'),
-	  CHROOT => 0,
 	  PRIORITY => 0,
 	});
 
@@ -119,7 +118,6 @@ sub pipe_query_out {
 	  USER => $self->get_conf('USERNAME'),
 	  PIPE => 'out',
 	  STREAMOUT => $devnull,
-	  CHROOT => 0,
 	  PRIORITY => 0,
 	});
 
