@@ -26,7 +26,7 @@ use warnings;
 use POSIX;
 use Dpkg::Arch;
 use Sbuild qw(isin usage_error version_less version_lesseq version_eq version_compare);
-use WannaBuild::Conf;
+use WannaBuild::Conf qw();
 use Sbuild::Sysconfig;
 use Sbuild::DB::Info;
 use Sbuild::DB::MLDBM;
